@@ -1,8 +1,8 @@
 import click
 
-from CveXplore.cli_cmds.single_collection import commands as group1
+from CveXplore.cli_cmds.search_cmds import commands as group1
 from CveXplore.cli_cmds.cve_cmds import commands as group2
-from CveXplore.cli_cmds.stats import commands as group3
+from CveXplore.cli_cmds.stats_cmds import commands as group3
 from CveXplore.cli_cmds.db_cmds import commands as group4
 from CveXplore.main import CveXplore
 
@@ -17,7 +17,7 @@ def main(ctx, version):
         exit(0)
 
 
-main.add_command(group1.single_collection_cmd)
+main.add_command(group1.search_cmd)
 main.add_command(group2.cve_cmd)
 main.add_command(group3.stats_cmd)
 main.add_command(group4.db_cmd)
